package cn.iocoder.yudao.module.system.api.dict;

import cn.iocoder.yudao.framework.dict.core.dto.DictDataRespDTO;

import java.util.Collection;
import java.util.List;

/**
 * 字典数据 API 接口
 *
 * @author 捷道源码
 */
public interface DictDataApi {

    /**
     * 校验字典数据们是否有效。如下情况，视为无效：
     * 1. 字典数据不存在
     * 2. 字典数据被禁用
     *
     * @param dictType 字典类型
     * @param values   字典数据值的数组
     */
    void validDictDatas(String dictType, Collection<String> values);

    /**
     * 获得指定类型的字典数据，从缓存中
     *
     * @param type 字典类型
     * @return 字典数据列表
     */
    List<DictDataRespDTO> listDictDatasFromCache(String type);

    /**
     * 获得指定类型的字典数据，从缓存中
     *
     * @param type  字典类型
     * @param label 字典数据标签
     * @return 字典数据列表
     */
    DictDataRespDTO parseDictDataFromCache(String type, String label);

    /**
     * 获得指定类型的字典数据，从缓存中
     *
     * @param type 字典类型
     * @return 启用的字典数据列表
     */
    List<DictDataRespDTO> getDictDatas(String type);
}
