package cn.iocoder.yudao.module.system.api.user;

import cn.iocoder.yudao.module.system.api.user.dto.AdminUserRespDTO;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Admin 用户 API 接口
 *
 * @author 捷道源码
 */
public interface AdminUserApi {

    /**
     * 通过用户 ID 查询用户
     *
     * @param id 用户ID
     * @return 用户对象信息
     */
    AdminUserRespDTO getUser(Long id);

    /**
     * 获得指定部门的用户数组
     *
     * @param deptIds 部门数组
     * @return 用户数组
     */
    List<AdminUserRespDTO> getUsersByDeptIds(Collection<Long> deptIds);

    /**
     * 获得指定岗位的用户数组
     *
     * @param postIds 岗位数组
     * @return 用户数组
     */
    List<AdminUserRespDTO> getUsersByPostIds(Collection<Long> postIds);

    /**
     * 获得用户 Map
     *
     * @param ids 用户编号数组
     * @return 用户 Map
     */
    Map<Long, AdminUserRespDTO> getUserMap(Collection<Long> ids);

    /**
     * 校验用户们是否有效。如下情况，视为无效：
     * 1. 用户编号不存在
     * 2. 用户被禁用
     *
     * @param ids 用户编号数组
     */
    void validUsers(Set<Long> ids);

    List<AdminUserRespDTO> getUsers(Collection<Long> ids);

    Long getActiveCustomerServicePostId();

    String getUserName(String userId);

    Long getUserDeptId(Long userId);

    /**
     * 判断当前用户是否中国总公司员工
     *
     * @param userId 用户id
     * @return
     */
    Boolean getUserNameIsChina(Long userId);

    /**
     * 判断用户是否具有某权限
     * @param userId
     * @param permissionCode
     * @return
     */
    Boolean hasPermissionByUserId(Long userId, String permissionCode);

}
