package cn.iocoder.yudao.module.system.api.user;

import cn.iocoder.yudao.module.system.api.user.dto.AdminUserRespDTO;
import cn.iocoder.yudao.module.system.convert.user.UserConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.user.AdminUserDO;
import cn.iocoder.yudao.module.system.service.user.AdminUserService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.USER_NOT_EXISTS;

/**
 * Admin 用户 API 实现类
 *
 * @author 捷道源码
 */
@Service
public class AdminUserApiImpl implements AdminUserApi {

    @Resource
    private AdminUserService userService;


    @Override
    public AdminUserRespDTO getUser(Long id) {
        AdminUserDO user = userService.getUser(id);
        return UserConvert.INSTANCE.convert4(user);
    }

    @Override
    public List<AdminUserRespDTO> getUsersByDeptIds(Collection<Long> deptIds) {
        List<AdminUserDO> users = userService.getUsersByDeptIds(deptIds);
        return UserConvert.INSTANCE.convertList4(users);
    }

    @Override
    public List<AdminUserRespDTO> getUsersByPostIds(Collection<Long> postIds) {
        List<AdminUserDO> users = userService.getUsersByPostIds(postIds);
        return UserConvert.INSTANCE.convertList4(users);
    }

    @Override
    public Map<Long, AdminUserRespDTO> getUserMap(Collection<Long> ids) {
        Map<Long, AdminUserDO> userMap = userService.getUserMap(ids);
        return UserConvert.INSTANCE.convertMap4(userMap);
    }

    @Override
    public void validUsers(Set<Long> ids) {
        userService.validUsers(ids);
    }

    @Override
    public List<AdminUserRespDTO> getUsers(Collection<Long> ids) {
        return UserConvert.INSTANCE.convertList4(userService.getUsers(ids));
    }

    @Override
    public Long getActiveCustomerServicePostId() {
        return userService.getActiveCustomerServicePostId();
    }

    @Override
    public String getUserName(String userId) {
        if (StringUtils.isEmpty(userId)) return "";
        AdminUserRespDTO user = getUser(Long.valueOf(userId));
        if (user == null) return "";
        return user.getNickname();
    }

    @Override
    public Long getUserDeptId(Long userId) {
        AdminUserDO user = userService.getUser(userId);
        if (user == null) {
            throw exception(USER_NOT_EXISTS);
        }
        return user.getDeptId();
    }


    @Override
    public Boolean getUserNameIsChina(Long userId) {
        return userService.getUserNameIsChina(userId);
    }

    @Override
    public Boolean hasPermissionByUserId(Long userId, String permissionCode) {
        return userService.hasPermissionByUserId(userId, permissionCode);
    }

}
