package cn.iocoder.yudao.module.system.controller.admin.helpDoc;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.system.vo.helpDoc.*;
import cn.iocoder.yudao.module.system.dal.dataobject.helpDoc.HelpDocDO;
import cn.iocoder.yudao.module.system.convert.helpDoc.HelpDocConvert;
import cn.iocoder.yudao.module.system.service.helpDoc.HelpDocService;

@Validated
@RestController
@Api(tags = "管理后台 - 帮助文档")
@RequestMapping("/system/help-doc")
public class HelpDocController {

    @Resource
    private HelpDocService helpDocService;

    @PostMapping("/create")
    @ApiOperation("创建帮助文档")
    @PreAuthorize("@ss.hasPermission('system:help-doc:create')")
    public CommonResult<Long> createHelpDoc(@Valid @RequestBody HelpDocCreateReqVO createReqVO) {
        return success(helpDocService.createHelpDoc(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新帮助文档")
    @PreAuthorize("@ss.hasPermission('system:help-doc:update')")
    public CommonResult<Boolean> updateHelpDoc(@Valid @RequestBody HelpDocUpdateReqVO updateReqVO) {
        helpDocService.updateHelpDoc(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除帮助文档")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:help-doc:delete')")
    public CommonResult<Boolean> deleteHelpDoc(@RequestParam("id") Long id) {
        helpDocService.deleteHelpDoc(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得帮助文档")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:help-doc:query')")
    public CommonResult<HelpDocBackVO> getHelpDoc(@RequestParam("id") Long id) {
        HelpDocDO helpDoc = helpDocService.getHelpDoc(id);
        return success(HelpDocConvert.INSTANCE.convert(helpDoc));
    }

    @GetMapping("/list")
    @ApiOperation("获得帮助文档列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('system:help-doc:query')")
    public CommonResult<List<HelpDocBackVO>> getHelpDocList(@RequestParam("ids") Collection<Long> ids) {
        List<HelpDocDO> list = helpDocService.getHelpDocList(ids);
        return success(HelpDocConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得帮助文档分页")
    @PreAuthorize("@ss.hasPermission('system:help-doc:query')")
    public CommonResult<PageResult<HelpDocBackVO>> getHelpDocPage(@Valid HelpDocQueryVO query, PageVO page) {
        PageResult<HelpDocDO> pageResult = helpDocService.getHelpDocPage(query, page);
        return success(HelpDocConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出帮助文档 Excel")
    @PreAuthorize("@ss.hasPermission('system:help-doc:export')")
    @OperateLog(type = EXPORT)
    public void exportHelpDocExcel(@Valid HelpDocQueryVO query,
              HttpServletResponse response) throws IOException {
        List<HelpDocDO> list = helpDocService.getHelpDocList(query);
        // 导出 Excel
        List<HelpDocBackVO> datas = HelpDocConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "帮助文档.xls", "数据", HelpDocBackVO.class, datas);
    }
}
