package cn.iocoder.yudao.module.system.controller.admin.internalHelpDoc;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.system.vo.internalHelpDoc.*;
import cn.iocoder.yudao.module.system.dal.dataobject.internalHelpDoc.InternalHelpDocDO;
import cn.iocoder.yudao.module.system.convert.internalHelpDoc.InternalHelpDocConvert;
import cn.iocoder.yudao.module.system.service.internalHelpDoc.InternalHelpDocService;

@Validated
@RestController
@Api(tags = "管理后台 - 对内帮助文档")
@RequestMapping("/system/internal-help-doc")
public class InternalHelpDocController {

    @Resource
    private InternalHelpDocService internalHelpDocService;

    @PostMapping("/create")
    @ApiOperation("创建对内帮助文档")
    @PreAuthorize("@ss.hasPermission('system:internal-help-doc:create')")
    public CommonResult<Long> createInternalHelpDoc(@Valid @RequestBody InternalHelpDocCreateReqVO createReqVO) {
        return success(internalHelpDocService.createInternalHelpDoc(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新对内帮助文档")
    @PreAuthorize("@ss.hasPermission('system:internal-help-doc:update')")
    public CommonResult<Boolean> updateInternalHelpDoc(@Valid @RequestBody InternalHelpDocUpdateReqVO updateReqVO) {
        internalHelpDocService.updateInternalHelpDoc(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除对内帮助文档")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:internal-help-doc:delete')")
    public CommonResult<Boolean> deleteInternalHelpDoc(@RequestParam("id") Long id) {
        internalHelpDocService.deleteInternalHelpDoc(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得对内帮助文档")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<InternalHelpDocBackVO> getInternalHelpDoc(@RequestParam("id") Long id) {
        InternalHelpDocDO internalHelpDoc = internalHelpDocService.getInternalHelpDoc(id);
        return success(InternalHelpDocConvert.INSTANCE.convert(internalHelpDoc));
    }

    @GetMapping("/list")
    @ApiOperation("获得对内帮助文档列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('system:internal-help-doc:query')")
    public CommonResult<List<InternalHelpDocBackVO>> getInternalHelpDocList(@RequestParam("ids") Collection<Long> ids) {
        List<InternalHelpDocDO> list = internalHelpDocService.getInternalHelpDocList(ids);
        return success(InternalHelpDocConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得对内帮助文档分页")
    @PreAuthorize("@ss.hasPermission('system:internal-help-doc:query')")
    public CommonResult<PageResult<InternalHelpDocBackVO>> getInternalHelpDocPage(@Valid InternalHelpDocQueryVO query, PageVO page) {
        PageResult<InternalHelpDocDO> pageResult = internalHelpDocService.getInternalHelpDocPage(query, page);
        return success(InternalHelpDocConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出对内帮助文档 Excel")
    @PreAuthorize("@ss.hasPermission('system:internal-help-doc:export')")
    @OperateLog(type = EXPORT)
    public void exportInternalHelpDocExcel(@Valid InternalHelpDocQueryVO query,
              HttpServletResponse response) throws IOException {
        List<InternalHelpDocDO> list = internalHelpDocService.getInternalHelpDocList(query);
        // 导出 Excel
        List<InternalHelpDocBackVO> datas = InternalHelpDocConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "对内帮助文档.xls", "数据", InternalHelpDocBackVO.class, datas);
    }
}
