package cn.iocoder.yudao.module.system.controller.admin.mail;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.system.controller.admin.mail.vo.account.*;
import cn.iocoder.yudao.module.system.convert.mail.MailAccountConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.mail.MailAccountDO;
import cn.iocoder.yudao.module.system.service.mail.MailAccountService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Comparator;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Api(tags = "管理后台 - 邮件账号")
@RestController
@RequestMapping("/system/mail-account")
public class MailAccountController {
    @Resource
    private MailAccountService mailAccountService;

    @PostMapping("/create")
    @ApiOperation("创建邮箱帐号")
    @PreAuthorize("@ss.hasPermission('system:mail-account:create')")
    public CommonResult<Long> createMailAccount(@Valid @RequestBody MailAccountCreateReqVO createReqVO) {
        return success(mailAccountService.create(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新邮箱帐号")
    @PreAuthorize("@ss.hasPermission('system:mail-account:update')")
    public CommonResult<Boolean> updateMailAccount(@Valid @RequestBody MailAccountUpdateReqVO updateReqVO) {
        mailAccountService.update(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除邮箱帐号")
    @ApiImplicitParam(name = "id", value = "编号", required = true, dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:mail-account:delete')")
    public CommonResult<Boolean> deleteMailAccount(@RequestParam("id") Long id) {
        mailAccountService.delete(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得邮箱帐号")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:mail-account:query')")
    public CommonResult<MailAccountRespVO> getMailAccount(@RequestParam("id") Long id) {
        MailAccountDO mailAccount = mailAccountService.getMailAccount(id);
        return success(MailAccountConvert.INSTANCE.convert(mailAccount));
    }

    //@GetMapping("/list")
    //@ApiOperation("获得邮箱帐号列表")
    //@ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    //@PreAuthorize("@ss.hasPermission('system:mail-account:query')")
    //public CommonResult<List<MailAccountRespVO>> getMailAccountList(@RequestParam("ids") Collection<Long> ids) {
    //    List<MailAccountDO> list = mailAccountService.getMailAccountList(ids);
    //    return success(MailAccountConvert.INSTANCE.convertList(list));
    //}

    @GetMapping("/page")
    @ApiOperation("获得邮箱帐号分页")
    @PreAuthorize("@ss.hasPermission('system:mail-account:query')")
    public CommonResult<PageResult<MailAccountRespVO>> getMailAccountPage(@Valid MailAccountPageReqVO pageVO) {
        PageResult<MailAccountDO> pageResult = mailAccountService.getMailAccountPage(pageVO);
        return success(MailAccountConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出邮箱帐号 Excel")
    @PreAuthorize("@ss.hasPermission('system:mail-account:export')")
    @OperateLog(type = EXPORT)
    public void exportMailAccountExcel(@Valid MailAccountExportReqVO exportReqVO,
                                       HttpServletResponse response) throws IOException {
        List<MailAccountDO> list = mailAccountService.getMailAccountList(exportReqVO);
        // 导出 Excel
        List<MailAccountExcelVO> datas = MailAccountConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "邮箱帐号.xls", "数据", MailAccountExcelVO.class, datas);
    }

    @GetMapping("/list-all-simple")
    @ApiOperation(value = "获得邮箱账号精简列表")
    public CommonResult<List<MailAccountExcelVO>> getSimpleMailAccountList() {
        List<MailAccountDO> list = mailAccountService.getMailAccountList();
        // 排序后，返回给前端
        list.sort(Comparator.comparing(MailAccountDO::getId));
        return success(MailAccountConvert.INSTANCE.convertList02(list));
    }

}
