package cn.iocoder.yudao.module.system.controller.admin.mail;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.system.controller.admin.mail.vo.template.*;
import cn.iocoder.yudao.module.system.convert.mail.MailTemplateConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.mail.MailTemplateDO;
import cn.iocoder.yudao.module.system.service.mail.MailSendService;
import cn.iocoder.yudao.module.system.service.mail.MailTemplateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Comparator;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Api(tags = "管理后台 - 邮件模版")
@RestController
@RequestMapping("/system/mail-template")
public class MailTemplateController {

    // TODO @wangjingyi：private DONE
    @Autowired
    private MailTemplateService mailTemplateService;

    @Autowired
    private MailSendService mailSendService;

    @PostMapping("/create")
    @ApiOperation("创建邮箱模版")
    @PreAuthorize("@ss.hasPermission('system:mail-template:create')")
    public CommonResult<Long> createMailTemplate(@Valid @RequestBody MailTemplateCreateReqVO createReqVO){
        return success(mailTemplateService.create(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("修改邮箱模版")
    @PreAuthorize("@ss.hasPermission('system:mail-template:update')")
    public CommonResult<Boolean> updateMailTemplate(@Valid @RequestBody MailTemplateUpdateReqVO updateReqVO){
        mailTemplateService.update(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除邮箱模版")
    @ApiImplicitParam(name = "id", value = "编号", required = true, dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:mail-template:delete')")
    public CommonResult<Boolean> deleteMailTemplate(@RequestParam("id") Long id) {
        mailTemplateService.delete(id);
        return success(true);
    }

    // TODO @wangjingyi：下面几个 VO 也参考我在 account 给的建议 DONE RespVO中需要BaseVO 中哪些字段

    @GetMapping("/get")
    @ApiOperation("获得邮箱模版")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:mail-template:get')")
    public CommonResult<MailTemplateRespVO> getMailTemplate(@RequestParam("id") Long id) {
        MailTemplateDO mailTemplateDO = mailTemplateService.getMailTemplate(id);
        return success(MailTemplateConvert.INSTANCE.convert(mailTemplateDO));
    }

    @GetMapping("/page")
    @ApiOperation("获得邮箱模版分页")
    @PreAuthorize("@ss.hasPermission('system:mail-template:query')")
    public CommonResult<PageResult<MailTemplateRespVO>> getMailTemplatePage(@Valid MailTemplatePageReqVO pageReqVO) {
        PageResult<MailTemplateDO> pageResult = mailTemplateService.getMailTemplatePage(pageReqVO);
        return success(MailTemplateConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/list-all-simple")
    @ApiOperation(value = "获得邮箱模版精简列表")
    public CommonResult<List<MailTemplateRespVO>> getSimpleTemplateList() {
        List<MailTemplateDO> list = mailTemplateService.getMailTemplateList();
        // 排序后，返回给前端
        list.sort(Comparator.comparing(MailTemplateDO::getId));
        return success(MailTemplateConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出邮箱模板 Excel")
    @PreAuthorize("@ss.hasPermission('system:mail-template:export')")
    @OperateLog(type = EXPORT)
    public void exportMailTemplateExcel(@Valid MailTemplateExportReqVO exportReqVO,
                                        HttpServletResponse response) throws IOException {
        List<MailTemplateDO> list = mailTemplateService.getMailTemplateList(exportReqVO);
        // 导出 Excel
        List<MailTemplateExcelVO> datas = MailTemplateConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "邮箱模板.xls", "数据", MailTemplateExcelVO.class, datas);
    }

    @PostMapping("/send-mail")
    @ApiOperation("发送邮件")
    @PreAuthorize("@ss.hasPermission('system:sms-template:send-mail')")
    public CommonResult<Long> sendMail(@Valid @RequestBody MailTemplateSendReqVO sendReqVO) {

        return success(mailSendService.sendMail(sendReqVO));
    }
}
