package cn.iocoder.yudao.module.system.controller.admin.needKnow;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.system.convert.needKnow.NeedKnowConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.needKnow.NeedKnowDO;
import cn.iocoder.yudao.module.system.service.needKnow.NeedKnowService;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowBackVO;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowCreateReqVO;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowQueryVO;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowUpdateReqVO;
import com.itextpdf.text.Chunk;
import com.itextpdf.text.Document;
import com.itextpdf.text.PageSize;
import com.itextpdf.text.pdf.PdfWriter;
import com.itextpdf.tool.xml.XMLWorkerHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.ByteArrayInputStream;
import java.net.URLEncoder;
import java.nio.charset.Charset;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.NEED_KNOW_NOT_EXISTS;

@Validated
@RestController
@Api(tags = "管理后台 - 须知")
@RequestMapping("/system/need-know")
public class NeedKnowController {

    @Resource
    private NeedKnowService needKnowService;

    @Value("${ue.root-path}")
    private String prePath;

    @PostMapping("/create")
    @ApiOperation("创建须知")
    @PreAuthorize("@ss.hasPermission('system:need-know:create')")
    public CommonResult<Long> createNeedKnow(@Valid @RequestBody NeedKnowCreateReqVO createReqVO) {
        return success(needKnowService.createNeedKnow(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新须知")
    @PreAuthorize("@ss.hasPermission('system:need-know:update')")
    public CommonResult<Boolean> updateNeedKnow(@Valid @RequestBody NeedKnowUpdateReqVO updateReqVO) {
        needKnowService.updateNeedKnow(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除须知")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:need-know:delete')")
    public CommonResult<Boolean> deleteNeedKnow(@RequestParam("id") Long id) {
        needKnowService.deleteNeedKnow(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得须知")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:need-know:query')")
    public CommonResult<NeedKnowBackVO> getNeedKnow(@RequestParam("id") Long id) {
        NeedKnowDO needKnow = needKnowService.getNeedKnow(id);
        return success(NeedKnowConvert.INSTANCE.convert(needKnow));
    }

    @GetMapping("/getByKey")
    @ApiOperation("获得须知")
    @ApiImplicitParam(name = "key", value = "须知类型:warehousing:入仓,control:控货,controltransfer:控货转移,pricequery:价格查询,5:用户服务协议", required = true, example = "warehousing", dataTypeClass = String.class)
    public CommonResult<NeedKnowBackVO> getNeedKnowByKey(@RequestParam("key") String key) {
        NeedKnowDO needKnow = needKnowService.getNeedKnowByKey(key);
        if (needKnow == null) {
            return error(NEED_KNOW_NOT_EXISTS);
        } else {
            return success(NeedKnowConvert.INSTANCE.convert(needKnow));
        }
    }

    @GetMapping("/download")
    @ApiOperation("下载需知")
    @ApiImplicitParam(name = "id", value = "需知ID", required = true, example = "1024", dataTypeClass = Long.class)
    public void download(@RequestParam("id") Long id, HttpServletResponse response) {
        try {
            NeedKnowDO needKnow = needKnowService.getNeedKnow(id);
            String head = "<!DOCTYPE html>\n" +
                    "<html lang=\"en\">\n" +
                    "\n" +
                    "<head>\n" +
                    "    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"/>\n" +
                    "\n" +
                    "    <title>" + needKnow.getTitleZh() + "</title>\n" +
                    "    <style type=\"text/css\">\n" +
                    "\t\t.subs {\n" +
                    "\t\t\ttext-align: center;\n" +
                    "\t\t\tpadding-bottom: 30px;\n" +
                    "\t\t\tpadding-top: 10px;\n" +
                    "\t\t}\n" +
                    "\n" +
                    "\t\t.subs input[type='button'] {\n" +
                    "\t\t\twidth: 50px;\n" +
                    "\t\t\theight: 30px;\n" +
                    "\t\t\tbackground: #4e9cdd;\n" +
                    "\t\t\tborder: none;\n" +
                    "\t\t\tborder-radius: 5px;\n" +
                    "\t\t\tmargin-right: 10px;\n" +
                    "\t\t\tfont-size: 16px;\n" +
                    "\t\t\tcursor: pointer;\n" +
                    "\t\t\tcolor: #fff;\n" +
                    "\t\t}\n" +
                    "\t</style>\n" +
                    "</head>\n" +
                    "<body>";
            String foot = "</body>\n" +
                    "</html>";
            //下载
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode(needKnow.getTitleZh() + ".pdf", "UTF-8"));
            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            //设置打印后pdf的格式
            ServletOutputStream outputStream = response.getOutputStream();
            Document document = new Document(PageSize.A4, 60.5f, 60.5f, 33f, 33f);
            PdfWriter pdfWriter = PdfWriter.getInstance(document, outputStream);// outputStream可以自己指定位置或者是HttpServletResponse得到的输出流
            pdfWriter.setTagged();
            document.open();
            document.add(new Chunk(""));
            ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream((head + needKnow.getContentZh() + foot).getBytes());
            XMLWorkerHelper.getInstance().parseXHtml(pdfWriter, document, byteArrayInputStream, Charset.defaultCharset());
            document.close();
            byteArrayInputStream.close();
            outputStream.flush();
            outputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    @GetMapping("/list")
    @ApiOperation("获得须知列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('system:need-know:query')")
    public CommonResult<List<NeedKnowBackVO>> getNeedKnowList(@RequestParam("ids") Collection<Long> ids) {
        List<NeedKnowDO> list = needKnowService.getNeedKnowList(ids);
        return success(NeedKnowConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得须知分页")
    @PreAuthorize("@ss.hasPermission('system:need-know:query')")
    public CommonResult<PageResult<NeedKnowBackVO>> getNeedKnowPage(@Valid NeedKnowQueryVO query, PageVO page) {
        PageResult<NeedKnowDO> pageResult = needKnowService.getNeedKnowPage(query, page);
        return success(NeedKnowConvert.INSTANCE.convertPage(pageResult));
    }

}
