package cn.iocoder.yudao.module.system.controller.admin.version;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.system.vo.version.*;
import cn.iocoder.yudao.module.system.dal.dataobject.version.VersionDO;
import cn.iocoder.yudao.module.system.convert.version.VersionConvert;
import cn.iocoder.yudao.module.system.service.version.VersionService;

@Validated
@RestController
@Api(tags = "管理后台 - app版本管理")
@RequestMapping("/system/version")
public class VersionController {

    @Resource
    private VersionService versionService;

    @PostMapping("/create")
    @ApiOperation("创建app版本管理")
//    @PreAuthorize("@ss.hasPermission('system:version:create')")
    public CommonResult<Long> createVersion(@Valid @RequestBody VersionCreateReqVO createReqVO) {
        return success(versionService.createVersion(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新app版本管理")
//    @PreAuthorize("@ss.hasPermission('system:version:update')")
    public CommonResult<Boolean> updateVersion(@Valid @RequestBody VersionUpdateReqVO updateReqVO) {
        versionService.updateVersion(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除app版本管理")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('system:version:delete')")
    public CommonResult<Boolean> deleteVersion(@RequestParam("id") Long id) {
        versionService.deleteVersion(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得app版本管理")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('system:version:query')")
    public CommonResult<VersionBackVO> getVersion(@RequestParam("id") Long id) {
        VersionDO version = versionService.getVersion(id);
        return success(VersionConvert.INSTANCE.convert(version));
    }

    @GetMapping("/list")
    @ApiOperation("获得app版本管理列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('system:version:query')")
    public CommonResult<List<VersionBackVO>> getVersionList(@RequestParam("ids") Collection<Long> ids) {
        List<VersionDO> list = versionService.getVersionList(ids);
        return success(VersionConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/latestVersion")
    @ApiOperation("获得最新的版本")
    @ApiImplicitParams({
            @ApiImplicitParam(value = "应用类型(字典data_source)", name = "appType", required = true, example = "pdm", dataTypeClass = String.class),
            @ApiImplicitParam(value = "内部号", name = "versionCode", required = true, example = "2", dataTypeClass = Integer.class)
    })
    public CommonResult<VersionBackVO> getLatestVersion(@RequestParam("appType") String appType, @RequestParam("versionCode") Integer versionCode) {
        VersionDO versionDO = versionService.getLatestVersion(appType, versionCode);
        return success(VersionConvert.INSTANCE.convert(versionDO));
    }

    @GetMapping("/page")
    @ApiOperation("获得app版本管理分页")
//    @PreAuthorize("@ss.hasPermission('system:version:query')")
    public CommonResult<PageResult<VersionBackVO>> getVersionPage(@Valid VersionQueryVO query, PageVO page) {
        PageResult<VersionDO> pageResult = versionService.getVersionPage(query, page);
        return success(VersionConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出app版本管理 Excel")
    @PreAuthorize("@ss.hasPermission('system:version:export')")
    @OperateLog(type = EXPORT)
    public void exportVersionExcel(@Valid VersionQueryVO query,
              HttpServletResponse response) throws IOException {
        List<VersionDO> list = versionService.getVersionList(query);
        // 导出 Excel
        List<VersionBackVO> datas = VersionConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "app版本管理.xls", "数据", VersionBackVO.class, datas);
    }
}
