package cn.iocoder.yudao.module.system.controller.app.banner;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerBackVO;
import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerCreateReqVO;
import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerQueryVO;
import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerUpdateReqVO;
import cn.iocoder.yudao.module.system.convert.banner.BannerConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.banner.BannerDO;
import cn.iocoder.yudao.module.system.service.banner.BannerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "客户端 - 广告设置")
@RequestMapping("/ecw/banner")
public class AppBannerController {

    @Resource
    private BannerService bannerService;

    @PostMapping("/create")
    @ApiOperation("创建广告设置")
    @PreAuthenticated
    public CommonResult<Long> createBanner(@Valid @RequestBody BannerCreateReqVO createReqVO) {
        return success(bannerService.createBanner(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新广告设置")
    @PreAuthenticated
    public CommonResult<Boolean> updateBanner(@Valid @RequestBody BannerUpdateReqVO updateReqVO) {
        bannerService.updateBanner(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除广告设置")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteBanner(@RequestParam("id") Long id) {
        bannerService.deleteBanner(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得广告设置")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<BannerBackVO> getBanner(@RequestParam("id") Long id) {
        BannerDO banner = bannerService.getBanner(id);
        return success(BannerConvert.INSTANCE.convert(banner));
    }

    @GetMapping("/list")
    @ApiOperation("获得广告设置列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<BannerBackVO>> getBannerList(@RequestParam("ids") Collection<Long> ids) {
        List<BannerDO> list = bannerService.getBannerList(ids);
        return success(BannerConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得广告设置分页")
    @PreAuthenticated
    public CommonResult<PageResult<BannerBackVO>> getBannerPage(@Valid BannerQueryVO query, PageVO page) {
        PageResult<BannerDO> pageResult = bannerService.getBannerPage(query, page);
        return success(BannerConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出广告设置 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportBannerExcel(@Valid BannerQueryVO query,
              HttpServletResponse response) throws IOException {
        List<BannerDO> list = bannerService.getBannerList(query);
        // 导出 Excel
        List<BannerBackVO> datas = BannerConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "广告设置.xls", "数据", BannerBackVO.class, datas);
    }
}
