package cn.iocoder.yudao.module.system.controller.app.bannerPop;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;

import cn.iocoder.yudao.module.system.controller.admin.bannerPop.vo.BannerPopBackVO;
import cn.iocoder.yudao.module.system.controller.admin.bannerPop.vo.BannerPopCreateReqVO;
import cn.iocoder.yudao.module.system.controller.admin.bannerPop.vo.BannerPopQueryVO;
import cn.iocoder.yudao.module.system.controller.admin.bannerPop.vo.BannerPopUpdateReqVO;
import cn.iocoder.yudao.module.system.convert.bannerPop.BannerPopConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.bannerPop.BannerPopDO;
import cn.iocoder.yudao.module.system.service.bannerPop.BannerPopService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;


@Validated
@RestController
@Api(tags = "客户端 - 广告弹窗")
@RequestMapping("/ecw/banner-pop")
public class AppBannerPopController {

    @Resource
    private BannerPopService bannerPopService;

    @PostMapping("/create")
    @ApiOperation("创建广告弹窗")
    @PreAuthenticated
    public CommonResult<Long> createBannerPop(@Valid @RequestBody BannerPopCreateReqVO createReqVO) {
        return success(bannerPopService.createBannerPop(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新广告弹窗")
    @PreAuthenticated
    public CommonResult<Boolean> updateBannerPop(@Valid @RequestBody BannerPopUpdateReqVO updateReqVO) {
        bannerPopService.updateBannerPop(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除广告弹窗")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteBannerPop(@RequestParam("id") Long id) {
        bannerPopService.deleteBannerPop(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得广告弹窗")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<BannerPopBackVO> getBannerPop(@RequestParam("id") Long id) {
        BannerPopDO bannerPop = bannerPopService.getBannerPop(id);
        return success(BannerPopConvert.INSTANCE.convert(bannerPop));
    }

    @GetMapping("/list")
    @ApiOperation("获得广告弹窗列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<BannerPopBackVO>> getBannerPopList(@RequestParam("ids") Collection<Long> ids) {
        List<BannerPopDO> list = bannerPopService.getBannerPopList(ids);
        return success(BannerPopConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得广告弹窗分页")
    @PreAuthenticated
    public CommonResult<PageResult<BannerPopBackVO>> getBannerPopPage(@Valid BannerPopQueryVO query, PageVO page) {
        PageResult<BannerPopDO> pageResult = bannerPopService.getBannerPopPage(query, page);
        return success(BannerPopConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出广告弹窗 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportBannerPopExcel(@Valid BannerPopQueryVO query,
              HttpServletResponse response) throws IOException {
        List<BannerPopDO> list = bannerPopService.getBannerPopList(query);
        // 导出 Excel
        List<BannerPopBackVO> datas = BannerPopConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "广告弹窗.xls", "数据", BannerPopBackVO.class, datas);
    }
}
