package cn.iocoder.yudao.module.system.controller.app.downloadLog;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;
import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.DOWNLOAD_LOG_NOT_EXISTS;

import cn.iocoder.yudao.module.system.vo.downloadLog.*;
import cn.iocoder.yudao.module.system.dal.dataobject.downloadLog.DownloadLogDO;
import cn.iocoder.yudao.module.system.convert.downloadLog.DownloadLogConvert;
import cn.iocoder.yudao.module.system.service.downloadLog.DownloadLogService;

@Validated
@RestController
@Api(tags = "管理后台 - 下载日志")
@RequestMapping("/system/download-log")
public class AppDownloadLogController {

    @Resource
    private DownloadLogService downloadLogService;



    @GetMapping("/page")
    @ApiOperation("获得下载日志分页")
    public CommonResult<PageResult<DownloadLogBackVO>> getDownloadLogPage(@Valid DownloadLogQueryVO query, PageVO page) {
        if (Objects.isNull(query)){
            query = new DownloadLogQueryVO();
        }
        // 该分页列表只能获取当前登录用户操作的导出与下载数据
        query.setUserId(SecurityFrameworkUtils.getLoginUserId());
        query.setUserType(1);// 客户端登录用户
        PageResult<DownloadLogDO> pageResult = downloadLogService.getDownloadLogPage(query, page);
        return success(DownloadLogConvert.INSTANCE.convertPage(pageResult));
    }



    @GetMapping("/down/{id}")
    @ApiOperation("下载文件")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<String> down(@PathVariable("id") Long id) {
        Long userId = SecurityFrameworkUtils.getLoginUserId();
        DownloadLogDO downloadLogDO = downloadLogService.getDownloadLog(id);
        if (Objects.isNull(downloadLogDO) || downloadLogDO.getUserType() == 2 || !Objects.equals(downloadLogDO.getUserId(), userId)){
            return error(DOWNLOAD_LOG_NOT_EXISTS);
        }
        downloadLogDO.setDownNum(downloadLogDO.getDownNum() + 1);
        downloadLogService.updateById(downloadLogDO);
        return success(downloadLogDO.getDownloadUrl());
    }

    @GetMapping("/retry/{id}")
    @ApiOperation("重试")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> retry(@PathVariable("id") Long id) {
        downloadLogService.retry(id);
        return success(true);
    }


    @GetMapping("/del/{id}")
    @ApiOperation("删除")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> del(@PathVariable("id") Long id) {
        downloadLogService.del(id);
        return success(true);
    }

}
