package cn.iocoder.yudao.module.system.controller.app.helpDoc;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.module.system.convert.helpDoc.HelpDocConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.helpDoc.HelpDocDO;
import cn.iocoder.yudao.module.system.service.helpDoc.HelpDocService;
import cn.iocoder.yudao.module.system.vo.helpDoc.HelpDocBackVO;
import cn.iocoder.yudao.module.system.vo.helpDoc.HelpDocCreateReqVO;
import cn.iocoder.yudao.module.system.vo.helpDoc.HelpDocQueryVO;
import cn.iocoder.yudao.module.system.vo.helpDoc.HelpDocUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "客户端 - 帮助文档")
@RequestMapping("/system/help-doc")
public class AppHelpDocController {

    @Resource
    private HelpDocService helpDocService;

    @PostMapping("/create")
    @ApiOperation("创建帮助文档")
    @PreAuthenticated
    public CommonResult<Long> createHelpDoc(@Valid @RequestBody HelpDocCreateReqVO createReqVO) {
        return success(helpDocService.createHelpDoc(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新帮助文档")
    @PreAuthenticated
    public CommonResult<Boolean> updateHelpDoc(@Valid @RequestBody HelpDocUpdateReqVO updateReqVO) {
        helpDocService.updateHelpDoc(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除帮助文档")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteHelpDoc(@RequestParam("id") Long id) {
        helpDocService.deleteHelpDoc(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得帮助文档")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<HelpDocBackVO> getHelpDoc(@RequestParam("id") Long id) {
        HelpDocDO helpDoc = helpDocService.getHelpDoc(id);
        return success(HelpDocConvert.INSTANCE.convert(helpDoc));
    }

    @GetMapping("/list")
    @ApiOperation("获得帮助文档列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<HelpDocBackVO>> getHelpDocList(@RequestParam("ids") Collection<Long> ids) {
        List<HelpDocDO> list = helpDocService.getHelpDocList(ids);
        return success(HelpDocConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得帮助文档分页")
    @PreAuthenticated
    public CommonResult<PageResult<HelpDocBackVO>> getHelpDocPage(@Valid HelpDocQueryVO query, PageVO page) {
        query.setStatus(0);
        PageResult<HelpDocDO> pageResult = helpDocService.getHelpDocPage(query, page);
        return success(HelpDocConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出帮助文档 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportHelpDocExcel(@Valid HelpDocQueryVO query,
              HttpServletResponse response) throws IOException {
        List<HelpDocDO> list = helpDocService.getHelpDocList(query);
        // 导出 Excel
        List<HelpDocBackVO> datas = HelpDocConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "帮助文档.xls", "数据", HelpDocBackVO.class, datas);
    }
}
