package cn.iocoder.yudao.module.system.controller.app.version;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.system.convert.version.VersionConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.version.VersionDO;
import cn.iocoder.yudao.module.system.service.version.VersionService;
import cn.iocoder.yudao.module.system.vo.version.VersionBackVO;
import cn.iocoder.yudao.module.system.vo.version.VersionCreateReqVO;
import cn.iocoder.yudao.module.system.vo.version.VersionQueryVO;
import cn.iocoder.yudao.module.system.vo.version.VersionUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "客户端 - app版本管理")
@RequestMapping("/system/version")
public class AppVersionController {

    @Resource
    private VersionService versionService;

    @GetMapping("/latestVersion")
    @ApiOperation("获得最新的版本")
    @ApiImplicitParams({
            @ApiImplicitParam(value = "应用类型(字典data_source)", name = "appType", required = true, example = "pdm", dataTypeClass = String.class),
            @ApiImplicitParam(value = "内部号", name = "versionCode", required = true, example = "2", dataTypeClass = Integer.class)
    })
    public CommonResult<VersionBackVO> getLatestVersion(@RequestParam("appType") String appType, @RequestParam("versionCode") Integer versionCode) {
        VersionDO versionDO = versionService.getLatestVersion(appType, versionCode);
        return success(VersionConvert.INSTANCE.convert(versionDO));
    }

}
