package cn.iocoder.yudao.module.system.dal.mysql.mail;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.mapper.BaseMapperX;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.framework.mybatis.core.query.QueryWrapperX;
import cn.iocoder.yudao.module.system.controller.admin.mail.vo.account.MailAccountExportReqVO;
import cn.iocoder.yudao.module.system.controller.admin.mail.vo.account.MailAccountPageReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.mail.MailAccountDO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

import java.util.Date;
import java.util.List;

@Mapper
public interface MailAccountMapper extends BaseMapperX<MailAccountDO> {

    default PageResult<MailAccountDO> selectPage(MailAccountPageReqVO reqVO) {
        return selectPage(reqVO, new LambdaQueryWrapperX<MailAccountDO>()
                .likeIfPresent(MailAccountDO::getFromAddress, reqVO.getFromAddress())
                .likeIfPresent(MailAccountDO::getUsername, reqVO.getUsername())
                .betweenIfPresent(MailAccountDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(MailAccountDO::getId));
    }

    default List<MailAccountDO> selectList(MailAccountExportReqVO reqVO) {
        return selectList(new LambdaQueryWrapperX<MailAccountDO>()
                .likeIfPresent(MailAccountDO::getFromAddress, reqVO.getFromAddress())
                .likeIfPresent(MailAccountDO::getUsername, reqVO.getUsername())
                .betweenIfPresent(MailAccountDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(MailAccountDO::getId));
    }

    default MailAccountDO selectByUserName(String userName){
        return selectOne(new QueryWrapperX<MailAccountDO>()
                .eqIfPresent("username" , userName));
    }

    default MailAccountDO selectByUserNameAndId(String userName,Long id){
        return selectOne(new QueryWrapperX<MailAccountDO>()
                .eqIfPresent("username" , userName)
                .eqIfPresent("id" , id));
    }

    default MailAccountDO selectOneByFrom(String from){
        return selectOne(new QueryWrapperX<MailAccountDO>()
                .eqIfPresent("from_address" , from));
    }

    @Select("SELECT COUNT(*) FROM system_mail_account WHERE update_time > #{maxUpdateTime}")
    Long selectCountByUpdateTimeGt(Date maxUpdateTime);
}
