package cn.iocoder.yudao.module.system.job.log;

import cn.iocoder.yudao.framework.quartz.core.handler.JobHandler;
import cn.iocoder.yudao.framework.tenant.core.job.TenantJob;
import cn.iocoder.yudao.module.infra.api.infra.ApiAccessLogApi;
import cn.iocoder.yudao.module.infra.api.infra.ApiErrorLogApi;
import cn.iocoder.yudao.module.system.dal.mysql.logger.LoginLogMapper;
import cn.iocoder.yudao.module.system.dal.mysql.logger.OperateLogMapper;
import cn.iocoder.yudao.module.system.dal.mysql.sms.SmsLogMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * 删除30天前的系统相关日志 Job
 *
 * @author
 */
@Component
@TenantJob
@Slf4j
public class LogClearJob implements JobHandler {

    @Resource
    private LoginLogMapper loginLogMapper;
    @Resource
    private OperateLogMapper operateLogMapper;
    @Resource
    private ApiAccessLogApi apiAccessLogApi;
    @Resource
    private ApiErrorLogApi apiErrorLogApi;
    @Resource
    private SmsLogMapper smsLogMapper;

    @Override
    public String execute(String day) throws Exception {
        log.info("开始清理日志");
        // 清理登录日志
        int loginCount = loginLogMapper.clearLog(Integer.valueOf(day));
        // 清理操作日志
        int operateCount = operateLogMapper.clearLog(Integer.valueOf(day));
        // 清理访问日志
        int apiAccessCount = apiAccessLogApi.clearLog(Integer.valueOf(day));
        // 清理访问错误日志
        int apiErrorCount = apiErrorLogApi.clearLog(Integer.valueOf(day));
        // 清理短信日志，保留3个月的短信日志
        int smsCount = smsLogMapper.clearLog(Integer.valueOf(day));
        String msg = String.format("清理登录日志%s条，清理操作日志%s条，清理访问日志%s条，清理访问错误日志%s条，清理短信日志%s条", loginCount, operateCount, apiAccessCount, apiErrorCount, smsCount);
        log.info(msg);
        return msg;
    }
}
