package cn.iocoder.yudao.module.system.listener;

import cn.iocoder.yudao.module.system.dal.dataobject.downloadLog.DownloadLogDO;
import cn.iocoder.yudao.module.system.service.downloadLog.DownloadLogService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.data.redis.connection.Message;
import org.springframework.data.redis.listener.KeyExpirationEventMessageListener;
import org.springframework.data.redis.listener.RedisMessageListenerContainer;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

import static cn.iocoder.yudao.framework.redis.constant.Constant.FILE_DOWN_LOG_EXPIRED_KEY;

/**
 * @program: SpringCloud
 * @description: redis Key过期监听
 * @author: zhengYi
 * @create: 2023-08-26 02:44
 */
@Component
@Slf4j
public class KeyExpiredListener extends KeyExpirationEventMessageListener {

    @Resource
    private DownloadLogService downloadLogService;

    public KeyExpiredListener(RedisMessageListenerContainer listenerContainer) {
        super(listenerContainer);
    }

    @Override
    public void onMessage(Message message, byte[] pattern) {
        String key = message.toString();
        log.info("过期key:{}", key);
        if (key.startsWith(FILE_DOWN_LOG_EXPIRED_KEY)) {
            String id = key.replace(FILE_DOWN_LOG_EXPIRED_KEY, "");
            if (StringUtils.isNotBlank(id)) {
                downloadLogService.removeTemporaryFile(Long.parseLong(id));
            }
        }
    }
}

