package cn.iocoder.yudao.module.system.service.banner;

import java.util.*;
import javax.annotation.Resource;

import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerCreateReqVO;
import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerQueryVO;
import cn.iocoder.yudao.module.system.controller.admin.banner.vo.banner.BannerUpdateReqVO;
import cn.iocoder.yudao.module.system.convert.banner.BannerConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.banner.BannerDO;
import cn.iocoder.yudao.module.system.dal.mysql.banner.BannerMapper;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.BANNER_NOT_EXISTS;

/**
 * 广告设置 Service 实现类
 *
 * @author wlh
 */
@Service
@Validated
public class BannerServiceImpl extends AbstractService<BannerMapper, BannerDO> implements BannerService {

    @Resource
    private BannerMapper bannerMapper;

    @Override
    public Long createBanner(BannerCreateReqVO createReqVO) {
        // 插入
        BannerDO banner = BannerConvert.INSTANCE.convert(createReqVO);
        bannerMapper.insert(banner);
        // 返回
        return banner.getId();
    }

    @Override
    public void updateBanner(BannerUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateBannerExists(updateReqVO.getId());
        // 更新
        BannerDO updateObj = BannerConvert.INSTANCE.convert(updateReqVO);
        bannerMapper.updateById(updateObj);
    }

    @Override
    public void deleteBanner(Long id) {
        // 校验存在
        this.validateBannerExists(id);
        // 删除
        bannerMapper.deleteById(id);
    }

    private void validateBannerExists(Long id) {
        if (bannerMapper.selectById(id) == null) {
            throw exception(BANNER_NOT_EXISTS);
        }
    }

    @Override
    public BannerDO getBanner(Long id) {
        return bannerMapper.selectById(id);
    }

    @Override
    public List<BannerDO> getBannerList(Collection<Long> ids) {
        return bannerMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<BannerDO> getBannerPage(BannerQueryVO query, PageVO page) {
        return bannerMapper.selectPage(page, query);
    }

    @Override
    public List<BannerDO> getBannerList(BannerQueryVO query) {
        return bannerMapper.selectList(query);
    }
}
