package cn.iocoder.yudao.module.system.service.downloadLog;

import java.util.*;
import javax.validation.*;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.system.controller.admin.user.vo.user.UserMarkVO;
import cn.iocoder.yudao.module.system.mq.message.file.FileMakeMessage;
import cn.iocoder.yudao.module.system.vo.downloadLog.*;
import cn.iocoder.yudao.module.system.dal.dataobject.downloadLog.DownloadLogDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 下载日志 Service 接口
 *
 * @author 江楠
 */
public interface DownloadLogService extends IService<DownloadLogDO> {

    /**
     * 创建下载日志
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createDownloadLog(@Valid DownloadLogCreateReqVO createReqVO);

    /**
     * 更新下载日志
     *
     * @param updateReqVO 更新信息
     */
    void updateDownloadLog(@Valid DownloadLogUpdateReqVO updateReqVO);

    /**
     * 删除下载日志
     *
     * @param id 编号
     */
    void deleteDownloadLog(Long id);

    /**
     * 获得下载日志
     *
     * @param id 编号
     * @return 下载日志
     */
    DownloadLogDO getDownloadLog(Long id);

    /**
     * 获得下载日志列表
     *
     * @param ids 编号
     * @return 下载日志列表
     */
    List<DownloadLogDO> getDownloadLogList(Collection<Long> ids);

    /**
     * 获得下载日志分页
     *
     * @param page  分页查询
     * @param query 查询
     * @return 下载日志分页
     */
    PageResult<DownloadLogDO> getDownloadLogPage(DownloadLogQueryVO query, PageVO page);

    /**
     * 获得下载日志列表, 用于 Excel 导出
     *
     * @param query 查询
     * @return 下载日志列表
     */
    List<DownloadLogDO> getDownloadLogList(DownloadLogQueryVO query);

    /**
     * @param type          类型 {@link cn.iocoder.yudao.module.system.enums.download.DownloadTypeEnum}
     * @param temporaryFile 是否为临时文件
     * @param businessNo    业务编号
     * @param lang          国际化语言
     * @param name          业务名称
     * @param fileSuffix    文件后缀
     * @param userType      请求端口
     * @param requestParams 请求参数
     * @return 日志编号
     */
    Long sendFileMake(Integer type, Boolean temporaryFile, String businessNo, Integer lang, String name, String fileSuffix, Integer userType, String requestParams);

    /**
     * 导出业务执行
     *
     * @param message 消息
     */
    void doFileMake(FileMakeMessage message);

    void removeTemporaryFile(Long id);

    /**
     * 统计用户下载列表角标
     *
     * @param userType 端口 1 客户端 2 管理端
     * @param userId   用户id
     * @return
     */
    UserMarkVO markCount(Integer userType, Long userId);

    void retry(Long id);

    void del(Long id);
}
