package cn.iocoder.yudao.module.system.service.helpDoc;

import java.util.*;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.system.vo.helpDoc.*;
import cn.iocoder.yudao.module.system.dal.dataobject.helpDoc.HelpDocDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.system.convert.helpDoc.HelpDocConvert;
import cn.iocoder.yudao.module.system.dal.mysql.helpDoc.HelpDocMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.*;

/**
 * 帮助文档 Service 实现类
 *
 * @author jiuping
 */
@Service
@Validated
public class HelpDocServiceImpl extends AbstractService<HelpDocMapper, HelpDocDO> implements HelpDocService {

    @Resource
    private HelpDocMapper helpDocMapper;

    @Override
    public Long createHelpDoc(HelpDocCreateReqVO createReqVO) {
        // 插入
        HelpDocDO helpDoc = HelpDocConvert.INSTANCE.convert(createReqVO);
        helpDocMapper.insert(helpDoc);
        // 返回
        return helpDoc.getId();
    }

    @Override
    public void updateHelpDoc(HelpDocUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateHelpDocExists(updateReqVO.getId());
        // 更新
        HelpDocDO updateObj = HelpDocConvert.INSTANCE.convert(updateReqVO);
        helpDocMapper.updateById(updateObj);
    }

    @Override
    public void deleteHelpDoc(Long id) {
        // 校验存在
        this.validateHelpDocExists(id);
        // 删除
        helpDocMapper.deleteById(id);
    }

    private void validateHelpDocExists(Long id) {
        if (helpDocMapper.selectById(id) == null) {
            throw exception(HELP_DOC_NOT_EXISTS);
        }
    }

    @Override
    public HelpDocDO getHelpDoc(Long id) {
        return helpDocMapper.selectById(id);
    }

    @Override
    public List<HelpDocDO> getHelpDocList(Collection<Long> ids) {
        return helpDocMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<HelpDocDO> getHelpDocPage(HelpDocQueryVO query, PageVO page) {
        return helpDocMapper.selectPage(page, query);
    }

    @Override
    public List<HelpDocDO> getHelpDocList(HelpDocQueryVO query) {
        return helpDocMapper.selectList(query);
    }
}
