package cn.iocoder.yudao.module.system.service.internalHelpDoc;

import java.util.*;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.system.vo.internalHelpDoc.*;
import cn.iocoder.yudao.module.system.dal.dataobject.internalHelpDoc.InternalHelpDocDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.system.convert.internalHelpDoc.InternalHelpDocConvert;
import cn.iocoder.yudao.module.system.dal.mysql.internalHelpDoc.InternalHelpDocMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.*;

/**
 * 对内帮助文档 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class InternalHelpDocServiceImpl extends AbstractService<InternalHelpDocMapper, InternalHelpDocDO> implements InternalHelpDocService {

    @Resource
    private InternalHelpDocMapper internalHelpDocMapper;

    @Override
    public Long createInternalHelpDoc(InternalHelpDocCreateReqVO createReqVO) {
        // 插入
        InternalHelpDocDO internalHelpDoc = InternalHelpDocConvert.INSTANCE.convert(createReqVO);
        internalHelpDocMapper.insert(internalHelpDoc);
        // 返回
        return internalHelpDoc.getId();
    }

    @Override
    public void updateInternalHelpDoc(InternalHelpDocUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateInternalHelpDocExists(updateReqVO.getId());
        // 更新
        InternalHelpDocDO updateObj = InternalHelpDocConvert.INSTANCE.convert(updateReqVO);
        internalHelpDocMapper.updateById(updateObj);
    }

    @Override
    public void deleteInternalHelpDoc(Long id) {
        // 校验存在
        this.validateInternalHelpDocExists(id);
        // 删除
        internalHelpDocMapper.deleteById(id);
    }

    private void validateInternalHelpDocExists(Long id) {
        if (internalHelpDocMapper.selectById(id) == null) {
            throw exception(INTERNAL_HELP_DOC_NOT_EXISTS);
        }
    }

    @Override
    public InternalHelpDocDO getInternalHelpDoc(Long id) {
        return internalHelpDocMapper.selectById(id);
    }

    @Override
    public List<InternalHelpDocDO> getInternalHelpDocList(Collection<Long> ids) {
        return internalHelpDocMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<InternalHelpDocDO> getInternalHelpDocPage(InternalHelpDocQueryVO query, PageVO page) {
        return internalHelpDocMapper.selectPage(page, query);
    }

    @Override
    public List<InternalHelpDocDO> getInternalHelpDocList(InternalHelpDocQueryVO query) {
        return internalHelpDocMapper.selectList(query);
    }
}
