package cn.iocoder.yudao.module.system.service.needKnow;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.system.convert.needKnow.NeedKnowConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.needKnow.NeedKnowDO;
import cn.iocoder.yudao.module.system.dal.mysql.needKnow.NeedKnowMapper;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowCreateReqVO;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowQueryVO;
import cn.iocoder.yudao.module.system.vo.needKnow.NeedKnowUpdateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.NEED_KNOW_NOT_EXISTS;

/**
 * 需知 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class NeedKnowServiceImpl extends AbstractService<NeedKnowMapper, NeedKnowDO> implements NeedKnowService {

    @Resource
    private NeedKnowMapper needKnowMapper;

    @Override
    public Long createNeedKnow(NeedKnowCreateReqVO createReqVO) {
        // 插入
        NeedKnowDO needKnow = NeedKnowConvert.INSTANCE.convert(createReqVO);
        needKnowMapper.insert(needKnow);
        // 返回
        return needKnow.getId();
    }

    @Override
    public void updateNeedKnow(NeedKnowUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateNeedKnowExists(updateReqVO.getId());
        // 更新
        NeedKnowDO updateObj = NeedKnowConvert.INSTANCE.convert(updateReqVO);
        needKnowMapper.updateById(updateObj);
    }

    @Override
    public void deleteNeedKnow(Long id) {
        // 校验存在
        this.validateNeedKnowExists(id);
        // 删除
        needKnowMapper.deleteById(id);
    }

    private void validateNeedKnowExists(Long id) {
        if (needKnowMapper.selectById(id) == null) {
            throw exception(NEED_KNOW_NOT_EXISTS);
        }
    }

    @Override
    public NeedKnowDO getNeedKnow(Long id) {
        return needKnowMapper.selectById(id);
    }

    @Override
    public NeedKnowDO getNeedKnowByKey(String key) {
        LambdaQueryWrapper<NeedKnowDO> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(NeedKnowDO::getKnowType, key);
        queryWrapper.eq(NeedKnowDO::getStatus, "0");
        return this.getOne(queryWrapper);
    }

    @Override
    public List<NeedKnowDO> getNeedKnowList(Collection<Long> ids) {
        return needKnowMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<NeedKnowDO> getNeedKnowPage(NeedKnowQueryVO query, PageVO page) {
        return needKnowMapper.selectPage(page, query);
    }

    @Override
    public List<NeedKnowDO> getNeedKnowList(NeedKnowQueryVO query) {
        return needKnowMapper.selectList(query);
    }
}
