package cn.iocoder.yudao.module.system.service.version;

import java.util.*;
import javax.annotation.Resource;

import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.system.vo.version.*;
import cn.iocoder.yudao.module.system.dal.dataobject.version.VersionDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.system.convert.version.VersionConvert;
import cn.iocoder.yudao.module.system.dal.mysql.version.VersionMapper;

/**
 * app版本管理 Service 实现类
 *
 * @author wlh
 */
@Service
@Validated
public class VersionServiceImpl extends AbstractService<VersionMapper, VersionDO> implements VersionService {

    @Resource
    private VersionMapper versionMapper;

    @Override
    public Long createVersion(VersionCreateReqVO createReqVO) {
        // 插入
        VersionDO version = VersionConvert.INSTANCE.convert(createReqVO);
        versionMapper.insert(version);
        // 返回
        return version.getId();
    }

    @Override
    public void updateVersion(VersionUpdateReqVO updateReqVO) {
        // 更新
        VersionDO updateObj = VersionConvert.INSTANCE.convert(updateReqVO);
        versionMapper.updateById(updateObj);
    }

    @Override
    public void deleteVersion(Long id) {
        // 删除
        versionMapper.deleteById(id);
    }


    @Override
    public VersionDO getVersion(Long id) {
        return versionMapper.selectById(id);
    }

    @Override
    public List<VersionDO> getVersionList(Collection<Long> ids) {
        return versionMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<VersionDO> getVersionPage(VersionQueryVO query, PageVO page) {
        return versionMapper.selectPage(page, query);
    }

    @Override
    public List<VersionDO> getVersionList(VersionQueryVO query) {
        return versionMapper.selectList(query);
    }

    @Override
    public VersionDO getLatestVersion(String appType, Integer versionCode) {
        return versionMapper.selectOne(new LambdaQueryWrapperX<VersionDO>()
            .eq(VersionDO::getAppType, appType)
                .gt(VersionDO::getVersionCode, versionCode)
                .orderByDesc(VersionDO::getId)
                .last("limit 1")
        );
    }
}
